@@ -29,11 +29,8 @@ public:
 
     void renderCloseIcon() override;
     void renderMaximizeIcon() override;
-    void renderRestoreIcon() override;
+    void renderFloatIcon() override;
     void renderMinimizeIcon() override;
-    void renderKeepBehindIcon() override;
-    void renderKeepInFrontIcon() override;
-    void renderContextHelpIcon() override;
 
 private:
 };
